==> openshift-model-console-5.11.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleNotificationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleNotificationSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent<A>{
  public ConsoleNotificationSpecFluentImpl() {
  }
  public ConsoleNotificationSpecFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpec instance) {
    this.withBackgroundColor(instance.getBackgroundColor()); 
    this.withColor(instance.getColor()); 
    this.withLink(instance.getLink()); 
    this.withLocation(instance.getLocation()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String backgroundColor;
  private java.lang.String color;
  private io.fabric8.openshift.api.model.console.v1.LinkBuilder link;
  private java.lang.String location;
  private java.lang.String text;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBackgroundColor() {
    return this.backgroundColor;
  }
  public A withBackgroundColor(java.lang.String backgroundColor) {
    this.backgroundColor=backgroundColor; return (A) this;
  }
  public java.lang.Boolean hasBackgroundColor() {
    return this.backgroundColor != null;
  }
  
  /**
   * Method is deprecated. use withBackgroundColor instead.
   */
  @java.lang.Deprecated
  public A withNewBackgroundColor(java.lang.String arg0) {
    return (A)withBackgroundColor(new String(arg0));
  }
  public java.lang.String getColor() {
    return this.color;
  }
  public A withColor(java.lang.String color) {
    this.color=color; return (A) this;
  }
  public java.lang.Boolean hasColor() {
    return this.color != null;
  }
  
  /**
   * Method is deprecated. use withColor instead.
   */
  @java.lang.Deprecated
  public A withNewColor(java.lang.String arg0) {
    return (A)withColor(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildLink instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1.Link getLink() {
    return this.link!=null?this.link.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1.Link buildLink() {
    return this.link!=null?this.link.build():null;
  }
  public A withLink(io.fabric8.openshift.api.model.console.v1.Link link) {
    _visitables.get("link").remove(this.link);
    if (link!=null){ this.link= new io.fabric8.openshift.api.model.console.v1.LinkBuilder(link); _visitables.get("link").add(this.link);} return (A) this;
  }
  public java.lang.Boolean hasLink() {
    return this.link != null;
  }
  public A withNewLink(java.lang.String href,java.lang.String text) {
    return (A)withLink(new Link(href, text));
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> withNewLink() {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluentImpl.LinkNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> withNewLinkLike(io.fabric8.openshift.api.model.console.v1.Link item) {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluentImpl.LinkNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> editLink() {
    return withNewLinkLike(getLink());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> editOrNewLink() {
    return withNewLinkLike(getLink() != null ? getLink(): new io.fabric8.openshift.api.model.console.v1.LinkBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> editOrNewLinkLike(io.fabric8.openshift.api.model.console.v1.Link item) {
    return withNewLinkLike(getLink() != null ? getLink(): item);
  }
  public java.lang.String getLocation() {
    return this.location;
  }
  public A withLocation(java.lang.String location) {
    this.location=location; return (A) this;
  }
  public java.lang.Boolean hasLocation() {
    return this.location != null;
  }
  
  /**
   * Method is deprecated. use withLocation instead.
   */
  @java.lang.Deprecated
  public A withNewLocation(java.lang.String arg0) {
    return (A)withLocation(new String(arg0));
  }
  public java.lang.String getText() {
    return this.text;
  }
  public A withText(java.lang.String text) {
    this.text=text; return (A) this;
  }
  public java.lang.Boolean hasText() {
    return this.text != null;
  }
  
  /**
   * Method is deprecated. use withText instead.
   */
  @java.lang.Deprecated
  public A withNewText(java.lang.String arg0) {
    return (A)withText(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleNotificationSpecFluentImpl that = (ConsoleNotificationSpecFluentImpl) o;
    if (backgroundColor != null ? !backgroundColor.equals(that.backgroundColor) :that.backgroundColor != null) return false;
    if (color != null ? !color.equals(that.color) :that.color != null) return false;
    if (link != null ? !link.equals(that.link) :that.link != null) return false;
    if (location != null ? !location.equals(that.location) :that.location != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backgroundColor,  color,  link,  location,  text,  additionalProperties,  super.hashCode());
  }
  public class LinkNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1.LinkFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<N>> implements io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LinkNestedImpl(io.fabric8.openshift.api.model.console.v1.Link item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1.LinkBuilder(this, item);
    }
    LinkNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1.LinkBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1.LinkBuilder builder;
    public N and() {
      return (N) ConsoleNotificationSpecFluentImpl.this.withLink(builder.build());
    }
    public N endLink() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-5.12.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleNotificationSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleNotificationSpecFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent<A>{
  public ConsoleNotificationSpecFluentImpl() {
  }
  public ConsoleNotificationSpecFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpec instance) {
    this.withBackgroundColor(instance.getBackgroundColor()); 
    this.withColor(instance.getColor()); 
    this.withLink(instance.getLink()); 
    this.withLocation(instance.getLocation()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String backgroundColor;
  private java.lang.String color;
  private io.fabric8.openshift.api.model.console.v1.LinkBuilder link;
  private java.lang.String location;
  private java.lang.String text;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBackgroundColor() {
    return this.backgroundColor;
  }
  public A withBackgroundColor(java.lang.String backgroundColor) {
    this.backgroundColor=backgroundColor; return (A) this;
  }
  public java.lang.Boolean hasBackgroundColor() {
    return this.backgroundColor != null;
  }
  
  /**
   * Method is deprecated. use withBackgroundColor instead.
   */
  @java.lang.Deprecated
  public A withNewBackgroundColor(java.lang.String arg0) {
    return (A)withBackgroundColor(new String(arg0));
  }
  public java.lang.String getColor() {
    return this.color;
  }
  public A withColor(java.lang.String color) {
    this.color=color; return (A) this;
  }
  public java.lang.Boolean hasColor() {
    return this.color != null;
  }
  
  /**
   * Method is deprecated. use withColor instead.
   */
  @java.lang.Deprecated
  public A withNewColor(java.lang.String arg0) {
    return (A)withColor(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildLink instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.console.v1.Link getLink() {
    return this.link!=null?this.link.build():null;
  }
  public io.fabric8.openshift.api.model.console.v1.Link buildLink() {
    return this.link!=null?this.link.build():null;
  }
  public A withLink(io.fabric8.openshift.api.model.console.v1.Link link) {
    _visitables.get("link").remove(this.link);
    if (link!=null){ this.link= new io.fabric8.openshift.api.model.console.v1.LinkBuilder(link); _visitables.get("link").add(this.link);} return (A) this;
  }
  public java.lang.Boolean hasLink() {
    return this.link != null;
  }
  public A withNewLink(java.lang.String href,java.lang.String text) {
    return (A)withLink(new Link(href, text));
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> withNewLink() {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluentImpl.LinkNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> withNewLinkLike(io.fabric8.openshift.api.model.console.v1.Link item) {
    return new io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluentImpl.LinkNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> editLink() {
    return withNewLinkLike(getLink());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> editOrNewLink() {
    return withNewLinkLike(getLink() != null ? getLink(): new io.fabric8.openshift.api.model.console.v1.LinkBuilder().build());
  }
  public io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<A> editOrNewLinkLike(io.fabric8.openshift.api.model.console.v1.Link item) {
    return withNewLinkLike(getLink() != null ? getLink(): item);
  }
  public java.lang.String getLocation() {
    return this.location;
  }
  public A withLocation(java.lang.String location) {
    this.location=location; return (A) this;
  }
  public java.lang.Boolean hasLocation() {
    return this.location != null;
  }
  
  /**
   * Method is deprecated. use withLocation instead.
   */
  @java.lang.Deprecated
  public A withNewLocation(java.lang.String arg0) {
    return (A)withLocation(new String(arg0));
  }
  public java.lang.String getText() {
    return this.text;
  }
  public A withText(java.lang.String text) {
    this.text=text; return (A) this;
  }
  public java.lang.Boolean hasText() {
    return this.text != null;
  }
  
  /**
   * Method is deprecated. use withText instead.
   */
  @java.lang.Deprecated
  public A withNewText(java.lang.String arg0) {
    return (A)withText(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleNotificationSpecFluentImpl that = (ConsoleNotificationSpecFluentImpl) o;
    if (backgroundColor != null ? !backgroundColor.equals(that.backgroundColor) :that.backgroundColor != null) return false;
    if (color != null ? !color.equals(that.color) :that.color != null) return false;
    if (link != null ? !link.equals(that.link) :that.link != null) return false;
    if (location != null ? !location.equals(that.location) :that.location != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backgroundColor,  color,  link,  location,  text,  additionalProperties,  super.hashCode());
  }
  public class LinkNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1.LinkFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<N>> implements io.fabric8.openshift.api.model.console.v1.ConsoleNotificationSpecFluent.LinkNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    LinkNestedImpl(io.fabric8.openshift.api.model.console.v1.Link item) {
      this.builder = new io.fabric8.openshift.api.model.console.v1.LinkBuilder(this, item);
    }
    LinkNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.console.v1.LinkBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1.LinkBuilder builder;
    public N and() {
      return (N) ConsoleNotificationSpecFluentImpl.this.withLink(builder.build());
    }
    public N endLink() {
      return and();
    }
    
  }
  
}
